
# Type: default_curi_maps


ordered list of prefixcommon biocontexts to be fetched to resolve id prefixes and inline prefix variables

URI: [meta:default_curi_maps](https://w3id.org/biolink/biolinkml/meta/default_curi_maps)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
